@@ -5,7 +5,7 @@ use warnings;
 package Path::Tiny;
 # ABSTRACT: File path utility
 
-our $VERSION = '0.059';
+our $VERSION = '0.060';
 
 # Dependencies
 use Config;
@@ -432,8 +432,15 @@ sub absolute {
 #pod     path("foo.txt")->append_utf8(@data);
 #pod
 #pod Appends data to a file.  The file is locked with C<flock> prior to writing.  An
-#pod optional hash reference may be used to pass options.  The only option is
-#pod C<binmode>, which is passed to C<binmode()> on the handle used for writing.
+#pod optional hash reference may be used to pass options.  Valid options are:
+#pod
+#pod =for :list
+#pod * C<binmode>: passed to C<binmode()> on the handle used for writing.
+#pod * C<truncate>: truncates the file after locking and before appending
+#pod
+#pod The C<truncate> option is a way to replace the contents of a file
+#pod B<in place>, unlike L</spew> which writes to a temporary file and then
+#pod replaces the original (if it exists).
 #pod
 #pod C<append_raw> is like C<append> with a C<binmode> of C<:unix> for fast,
 #pod unbuffered, raw write.
@@ -442,17 +449,18 @@ sub absolute {
 #pod C<:unix:encoding(UTF-8)>.  If L<Unicode::UTF8> 0.58+ is installed, a raw
 #pod append will be done instead on the data encoded with C<Unicode::UTF8>.
 #pod
-#pod Current API available since 0.004.
+#pod Current API available since 0.060.
 #pod
 #pod =cut
 
 sub append {
     my ( $self, @data ) = @_;
     my $args = ( @data && ref $data[0] eq 'HASH' ) ? shift @data : {};
-    $args = _get_args( $args, qw/binmode/ );
+    $args = _get_args( $args, qw/binmode truncate/ );
     my $binmode = $args->{binmode};
     $binmode = ( ( caller(0) )[10] || {} )->{'open>'} unless defined $binmode;
-    my $fh = $self->filehandle( { locked => 1 }, ">>", $binmode );
+    my $mode = $args->{truncate} ? ">" : ">>";
+    my $fh = $self->filehandle( { locked => 1 }, $mode, $binmode );
     print {$fh} map { ref eq 'ARRAY' ? @$_ : $_ } @data;
     close $fh or $self->_throw('close');
 }
@@ -1373,6 +1381,12 @@ sub slurp_utf8 {
 #pod If L<Unicode::UTF8> 0.58+ is installed, a raw spew will be done instead on
 #pod the data encoded with C<Unicode::UTF8>.
 #pod
+#pod B<NOTE>: because the file is written to a temporary file and then renamed, the
+#pod new file will wind up with permissions based on your current umask.  This is a
+#pod feature to protect you from a race condition that would otherwise give
+#pod different permissions than you might expect.  If you really want to keep the
+#pod original mode flags, use L</append> with the C<truncate> option.
+#pod
 #pod Current API available since 0.011.
 #pod
 #pod =cut
@@ -1604,7 +1618,7 @@ Path::Tiny - File path utility
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 SYNOPSIS
 
@@ -1809,8 +1823,23 @@ Current API available since 0.001.
     path("foo.txt")->append_utf8(@data);
 
 Appends data to a file.  The file is locked with C<flock> prior to writing.  An
-optional hash reference may be used to pass options.  The only option is
-C<binmode>, which is passed to C<binmode()> on the handle used for writing.
+optional hash reference may be used to pass options.  Valid options are:
+
+=over 4
+
+=item *
+
+C<binmode>: passed to C<binmode()> on the handle used for writing.
+
+=item *
+
+C<truncate>: truncates the file after locking and before appending
+
+=back
+
+The C<truncate> option is a way to replace the contents of a file
+B<in place>, unlike L</spew> which writes to a temporary file and then
+replaces the original (if it exists).
 
 C<append_raw> is like C<append> with a C<binmode> of C<:unix> for fast,
 unbuffered, raw write.
@@ -1819,7 +1848,7 @@ C<append_utf8> is like C<append> with a C<binmode> of
 C<:unix:encoding(UTF-8)>.  If L<Unicode::UTF8> 0.58+ is installed, a raw
 append will be done instead on the data encoded with C<Unicode::UTF8>.
 
-Current API available since 0.004.
+Current API available since 0.060.
 
 =head2 basename
 
@@ -2235,6 +2264,12 @@ C<spew_utf8> is like C<spew> with a C<binmode> of C<:unix:encoding(UTF-8)>.
 If L<Unicode::UTF8> 0.58+ is installed, a raw spew will be done instead on
 the data encoded with C<Unicode::UTF8>.
 
+B<NOTE>: because the file is written to a temporary file and then renamed, the
+new file will wind up with permissions based on your current umask.  This is a
+feature to protect you from a race condition that would otherwise give
+different permissions than you might expect.  If you really want to keep the
+original mode flags, use L</append> with the C<truncate> option.
+
 Current API available since 0.011.
 
 =head2 stat, lstat
